﻿<?xml version="1.0"?>

<!-- XSL Stylesheet header -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
 xmlns:wow="http://mdbdoc.sourceforge.net/ns/1.0/" 
version="1.0" >
<xsl:output method="html" />
<xsl:template match="/">

<!-- HTML output header -->
<html lang="en">
<link rel="stylesheet" type="text/css" href="http://mdbdoc.sourceforge.net/mdbdoc151.css" title="MDB Doc Stylesheet" media="screen, print" />
<head>
<title>MDB Doc</title>
</head>
<body>
	<h1 id="mdbHeader">Database Information for file
	<xsl:value-of select="Database/Header/Filepath" /></h1>
	<table class="mdbtable">
	<caption>Key Data</caption>
	<thead>
		<tr>
			<th scope="col">Setting</th>
			<th scope="col">Value</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Application Name</td>
			<td>
				<xsl:value-of select="Database/Header/ApplicationName" />
			</td>
		</tr>
		<tr>
			<td>Is it compiled?</td>
			<td>
				<xsl:value-of select="Database/Header/IsCompiled" />
			</td>
		</tr>
		<tr>
			<td>Does it have a broken reference?</td>
			<td>
				<xsl:value-of select="Database/Header/BrokenReference" />
			</td>
		</tr>
		<tr>
			<td>Create date/time</td>
			<td>
				<xsl:value-of select="Database/Header/CreateDate" />
			</td>
		</tr>
	</tbody>
</table>

<!-- Start of contents list. It checks for a count of >0 entries in each section so that there 
will never be a link to a detail section with 0 items -->

<h1 id="mdbContents">Contents</h1>
<nav>
	<ul>
		<xsl:if test="count(Database/Properties/Property) > 0">
			<li><a href="#mdbDBProps">Database Properties</a></li>
		</xsl:if> 
		<xsl:if test="count(Database/Tables/Table) > 0">
			<li><a href="#mdbTables">Tables</a></li>
		</xsl:if> 
		<xsl:if test="count(Database/Queries/Query) > 0">
			<li><a href="#mdbQueries">Queries</a></li>
		</xsl:if> 
		<xsl:if test="count(Database/Macros/Macro) > 0">
			<li><a href="#mdbMacros">Macros</a></li>
		</xsl:if>
		<xsl:if test="count(Database/Modules/Module) > 0">
			<li><a href="#mdbModules">Modules</a></li>
		</xsl:if> 
		<xsl:if test="count(Database/Forms/Form) > 0">
			<li><a href="#mdbForms">Forms</a></li>
		</xsl:if>
		<xsl:if test="count(Database/Reports/Report) > 0">
			<li><a href="#mdbReports">Reports</a></li>
		</xsl:if>
		<xsl:if test="count(Database/References/Reference) > 0">
			<li><a href="#mdbReferences">References</a></li>
		</xsl:if>
		<xsl:if test="count(Database/Relations/Relation) > 0">
			<li><a href="#mdbRelations">Relations</a></li>
		</xsl:if>
		<xsl:if test="count(Database/Ribbons/Ribbon) > 0">
			<li><a href="#mdbRibbons">Ribbons</a></li>
		</xsl:if>
		<xsl:if test="count(Database/ImportExport_Specifications/ImpExpSpec) > 0">
			<li><a href="#mdbImpExpSpecs">Import/Export Specifications</a></li>
		</xsl:if>
		<xsl:if test="count(Database/DataAccessPages/DataAccessPage) > 0">
			<li><a href="#mdbDAPs">Data Access Pages</a></li>
		</xsl:if>
		<xsl:if test="count(Database/Commandbars/Commandbar) > 0">
			<li><a href="#mdbImpExpSpecs">Commandbars</a></li>
		</xsl:if>
	</ul>
</nav>

<!-- Database Properties section -->
<h1 id="mdbDBProps">Properties</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Property name</th>
			<th>Data Type</th>
			<th>Value</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Properties/Property">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="Type" /></td>
				<td><xsl:value-of select="Value" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>

<!-- Tables section -->
<h1 id="mdbTables">Tables</h1>
<table class="mdbtable">
<thead>
	<tr>
		<th>Table name</th>
		<th>Description</th>
		<th>Record count</th>
	</tr>
</thead>
	<tbody>
		<xsl:for-each select="Database/Tables/Table">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="Description" /></td>
				<td><xsl:value-of select="Recordcount" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>


<!-- Fields section. Nested loops - the first goes around tables, the second picks up fields within that table. -->
<h1 id="mdbTables">Fields</h1>
<xsl:for-each select="Database/Tables/Table">
<h2>Fields within table: <xsl:value-of select="Name" /></h2>

<table class="mdbtable">
	<thead>
		<tr>
			<th>Field name</th>
			<th>Data Type</th>
			<th>Description</th>
			<th>Default Value</th>
			<th>Required</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Fields/Field">
			<tr>
				<td><xsl:value-of select="Fieldname" /></td>
				<td><xsl:value-of select="Datatype" /></td>
				<td><xsl:value-of select="Description" /></td>
				<td><xsl:value-of select="DefaultValue" /></td>
				<td><xsl:value-of select="Required" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
</xsl:for-each>

<!-- Queries section -->
<h1 id="mdbQueries">Queries</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Query name</th>
			<th>Query Type</th>
			<th>SQL</th>
			<th>Description</th>
		</tr>
	</thead>
	<tbody>
	<xsl:for-each select="Database/Queries/Query">
		<xsl:sort select="Name" order="ascending" data-type="text" />
		<tr>
			<td><xsl:value-of select="Name" /></td>
			<td><xsl:value-of select="Type" /></td>
			<td><xsl:value-of select="SQL" /></td>
			<td><xsl:value-of select="Description" /></td>
		</tr>
	</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Macros section -->
<h1 id="mdbMacros">Macros</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Macro name</th>
			<th>Create Date</th>
			<th>Update Date</th>
			<th>Description</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Macros/Macro">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="CreateDate" /></td>
				<td><xsl:value-of select="UpdateDate" /></td>
				<td><xsl:value-of select="Description" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Modules section -->
<h1 id="mdbModules">Modules</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Module name</th>
			<th>Create Date</th>
			<th>Update Date</th>
			<th>Module Type</th>
			<th>No. Lines</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Modules/Module">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="CreateDate" /></td>
				<td><xsl:value-of select="UpdateDate" /></td>
				<td><xsl:value-of select="ModuleType" /></td>
				<td class="rightNum"><xsl:value-of select="NoLines" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Forms section -->
<h1 id="mdbForms">Forms</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Form name</th>
			<th>Create Date</th>
			<th>Update Date</th>
			<th>RecordSource</th>
			<th>Has Module</th>
			<th>Description</th>
		</tr>
	</thead>
	<tbody>
	<xsl:for-each select="Database/Forms/Form">
		<xsl:sort select="Name" order="ascending" data-type="text" />
		<tr>
			<td><xsl:value-of select="Name" /></td>
			<td><xsl:value-of select="CreateDate" /></td>
			<td><xsl:value-of select="UpdateDate" /></td>
			<td><xsl:value-of select="RecordSource" /></td>
			<td><xsl:value-of select="HasModule" /></td>
			<td><xsl:value-of select="Description" /></td>
		</tr>
	</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Reports section -->
<h1 id="mdbReports">Reports</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Report name</th>
			<th>Create Date</th>
			<th>Update Date</th>
			<th>RecordSource</th>
			<th>Has Module</th>
			<th>Description</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Reports/Report">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="CreateDate" /></td>
				<td><xsl:value-of select="UpdateDate" /></td>
				<td><xsl:value-of select="RecordSource" /></td>
				<td><xsl:value-of select="HasModule" /></td>
				<td><xsl:value-of select="Description" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- References section -->
<h1 id="mdbReferences">References</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Reference name</th>
			<th>Is Broken?</th>
			<th>Path</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/References/Reference">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="IsBroken" /></td>
				<td><xsl:value-of select="Path" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Relations section -->
<h1 id="mdbRelations">Relations</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Primary name</th>
			<th>Foreign name</th>
			<th>Description</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Relations/Relation">
			<xsl:sort select="PrimaryName" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="PrimaryName" /></td>
				<td><xsl:value-of select="ForeignName" /></td>
				<td><xsl:value-of select="Description" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Ribbons section -->
<h1 id="mdbRibbons">Ribbons</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Ribbon ID</th>
			<th>Ribbon Name</th>
			<th>XML</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Ribbons/Ribbon">
			<xsl:sort select="RibbonName" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="RibbonID" /></td>
				<td><xsl:value-of select="RibbonName" /></td>
				<td><code><xsl:value-of select="RibbonXML" /></code></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Import/Export specifications section -->
<h1 id="mdbImpExpSpecs">Import/Export Specifications</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Name</th>
			<th>XML code</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/ImportExport_Specifications/ImpExpSpec">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><code><xsl:value-of select="XML" /></code></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Data Access Pages section -->
<h1 id="mdbDAPs">Data Access Pages</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Name</th>
			<th>CreateDate</th>
			<th>UpdateDate</th>
			<th>ConnectionString</th>
			<th>Description</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/DataAccessPages/DataAccessPage">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="CreateDate" /></td>
				<td><xsl:value-of select="UpdateDateDate" /></td>
				<td><xsl:value-of select="ConnectionString" /></td>
				<td><xsl:value-of select="Description" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>


<!-- Commandbars section -->
<h1 id="mdbCommandbars">Commandbars</h1>
<table class="mdbtable">
	<thead>
		<tr>
			<th>Name</th>
			<th>NameLocal</th>
			<th>Visible</th>
		</tr>
	</thead>
	<tbody>
		<xsl:for-each select="Database/Commandbars/Commandbar">
			<xsl:sort select="Name" order="ascending" data-type="text" />
			<tr>
				<td><xsl:value-of select="Name" /></td>
				<td><xsl:value-of select="NameLocal" /></td>
				<td><xsl:value-of select="Visible" /></td>
			</tr>
		</xsl:for-each>
	</tbody>
</table>
<p><a href="#mdbContents">Return to contents</a></p>

<!-- Footer - end of HTML -->
<footer>
<p>This Database information report was generated using MDB Doc version 2.0.  MDB Doc is Copyright 2007-14 John Barnett.</p>
</footer>

</body>
</html>


</xsl:template>
</xsl:stylesheet>
